package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.BomanAnnex;

/**
 * 附件Mapper接口
 * 
 * @author boman
 * @date 2023-11-13
 */
public interface BomanAnnexMapper 
{
    /**
     * 查询附件
     * 
     * @param annexId 附件主键
     * @return 附件
     */
    public BomanAnnex selectBomanAnnexByAnnexId(Long annexId);

    /**
     * 查询附件列表
     * 
     * @param bomanAnnex 附件
     * @return 附件集合
     */
    public List<BomanAnnex> selectBomanAnnexList(BomanAnnex bomanAnnex);

    /**
     * 新增附件
     * 
     * @param bomanAnnex 附件
     * @return 结果
     */
    public int insertBomanAnnex(BomanAnnex bomanAnnex);
    public int batchBomanAnnex(List<BomanAnnex> bomanAnnex);

    /**
     * 修改附件
     * 
     * @param bomanAnnex 附件
     * @return 结果
     */
    public int updateBomanAnnex(BomanAnnex bomanAnnex);

    /**
     * 删除附件
     * 
     * @param annexId 附件主键
     * @return 结果
     */
    public int deleteBomanAnnexByAnnexId(Long annexId);

    /**
     * 批量删除附件
     * 
     * @param annexIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBomanAnnexByAnnexIds(Long[] annexIds);
}
